@@ -49,19 +49,19 @@ public class Repository {
     /** The base directory of the repository typically (/usr/share/maven-repo) */
     private File baseDir;
 
-    private Map<File, POMInfo> unresolvedPoms = new HashMap<File, POMInfo>();
+    private Map<File, POMInfo> unresolvedPoms = new HashMap<>();
 
     /** The dependency (groupId+artifactId+version+type) to pom mapping */
-    private Map<Dependency, POMInfo> dep2info = new HashMap<Dependency, POMInfo>();
+    private Map<Dependency, POMInfo> dep2info = new HashMap<>();
 
     /** The pom files specifying a parent pom not found in the repository */
-    private Map<File, POMInfo> pomsWithMissingParent = new HashMap<File, POMInfo>();
+    private Map<File, POMInfo> pomsWithMissingParent = new HashMap<>();
 
     /** The pom files specifying a plugin or a dependency without version */
-    private Map<File, POMInfo> pomsWithMissingVersions = new HashMap<File, POMInfo>();
+    private Map<File, POMInfo> pomsWithMissingVersions = new HashMap<>();
     
     /** The resolved poms, that is the poms with a resolved parent */
-    private Map<File, POMInfo> resolvedPoms = new HashMap<File, POMInfo>();
+    private Map<File, POMInfo> resolvedPoms = new HashMap<>();
 
     /** The Maven super pom defining the default plugins */
     private POMInfo superPom;
@@ -131,7 +131,7 @@ public class Repository {
     }
 
     protected List<POMInfo> getAllPoms() {
-        List<POMInfo> allPoms = new ArrayList<POMInfo>(resolvedPoms.values());
+        List<POMInfo> allPoms = new ArrayList<>(resolvedPoms.values());
         allPoms.addAll(unresolvedPoms.values());
         return allPoms;
     }
@@ -151,7 +151,7 @@ public class Repository {
             return pom;
         }
 
-        Map<DependencyRule, POMInfo> potentialMatches = new TreeMap<DependencyRule, POMInfo>();
+        Map<DependencyRule, POMInfo> potentialMatches = new TreeMap<>();
         for (POMInfo testPom : getAllPoms()) {
             Set<DependencyRule> rules = testPom.getPublishedRules();
             rules.add(MAVEN_PLUGINS_KEEP_VERSION_RULE);
@@ -171,7 +171,7 @@ public class Repository {
     }
 
     public List<POMInfo> searchMatchingPOMsIgnoreVersion(Dependency dependency) {
-        List<POMInfo> result = new ArrayList<POMInfo>();
+        List<POMInfo> result = new ArrayList<>();
         POMInfo pom = searchMatchingPOM(dependency);
         if (pom != null) {
             result.add(pom);
@@ -257,8 +257,8 @@ public class Repository {
             writer.printSectionEnd();
         }
 
-        Set<String> issues = new TreeSet<String>();
-        Map<File, List<Dependency>> pomsWithIssues = new HashMap<File, List<Dependency>>();
+        Set<String> issues = new TreeSet<>();
+        Map<File, List<Dependency>> pomsWithIssues = new HashMap<>();
         for (Entry<File, POMInfo> entry : resolvedPoms.entrySet()) {
             File pom = entry.getKey();
             POMInfo pomInfo = entry.getValue();
@@ -273,7 +273,7 @@ public class Repository {
                     issues.add("Unpackaged dependency: " + dependency + " in " + pom);
                     List<Dependency> pomIssues = pomsWithIssues.get(pom);
                     if (pomIssues == null) {
-                        pomIssues = new ArrayList<Dependency>();
+                        pomIssues = new ArrayList<>();
                         pomsWithIssues.put(pom, pomIssues);
                     }
                     pomIssues.add(dependency);
@@ -284,7 +284,7 @@ public class Repository {
                     issues.add("Unpackaged plugin: " + dependency + " in " + pom);
                     List<Dependency> pomIssues = pomsWithIssues.get(pom);
                     if (pomIssues == null) {
-                        pomIssues = new ArrayList<Dependency>();
+                        pomIssues = new ArrayList<>();
                         pomsWithIssues.put(pom, pomIssues);
                     }
                     pomIssues.add(dependency);
@@ -300,14 +300,14 @@ public class Repository {
         writer.printSectionEnd();
 
         // Find the poms with most issues
-        Map<Integer, List<File>> pomsWithNumberOfIssues = new TreeMap<Integer, List<File>>(Collections.reverseOrder());
+        Map<Integer, List<File>> pomsWithNumberOfIssues = new TreeMap<>(Collections.reverseOrder());
         for (Entry<File, List<Dependency>> entry : pomsWithIssues.entrySet()) {
             File pom = entry.getKey();
             List<Dependency> missingDeps = entry.getValue();
             int count = missingDeps.size();
             List<File> orderedPoms = pomsWithNumberOfIssues.get(count);
             if (orderedPoms == null) {
-                orderedPoms = new ArrayList<File>();
+                orderedPoms = new ArrayList<>();
                 pomsWithNumberOfIssues.put(count, orderedPoms);
             }
             orderedPoms.add(pom);
@@ -332,7 +332,7 @@ public class Repository {
         }
 
         // Find the dependencies that need packaging most
-        Map<Dependency, Integer> missingDependenciesCounts = new HashMap<Dependency, Integer>();
+        Map<Dependency, Integer> missingDependenciesCounts = new HashMap<>();
         for (Entry<File, List<Dependency>> entry : pomsWithIssues.entrySet()) {
             List<Dependency> missingDeps = entry.getValue();
             for (Dependency missingDependency : missingDeps) {
@@ -343,7 +343,7 @@ public class Repository {
                 missingDependenciesCounts.put(missingDependency, lastCount + 1);
             }
         }
-        List<Map.Entry<Dependency, Integer>> missingDependenciesCountList = new ArrayList<Map.Entry<Dependency, Integer>>(missingDependenciesCounts.entrySet());
+        List<Map.Entry<Dependency, Integer>> missingDependenciesCountList = new ArrayList<>(missingDependenciesCounts.entrySet());
         Collections.sort(missingDependenciesCountList, new Comparator<Map.Entry<Dependency, Integer>>() {
 
             public int compare(Map.Entry<Dependency, Integer> entry1, Map.Entry<Dependency, Integer> entry2) {
@@ -370,7 +370,7 @@ public class Repository {
 
     private void resolveAll(Map<File, POMInfo> file2pom) {
         // copy to avoid concurrent modifications
-        Map<File, POMInfo> copy = new HashMap<File, POMInfo>(file2pom);
+        Map<File, POMInfo> copy = new HashMap<>(file2pom);
         for (Entry<File, POMInfo> entry : copy.entrySet()) {
             try {
                 registerPom(entry.getKey(), entry.getValue());
