@@ -54,10 +54,9 @@ public class POMCleanerTest {
     public void testCleanMavenPom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("maven.xml");
-        boolean noParent = true;
         instance.getRulesFiles().addDefaultRules();
         instance.getRulesFiles().get(RULES).add(new DependencyRule("org.codehaus.plexus plexus-container-default jar s/1\\.0-alpha-.*/1.0-alpha/"));
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, true, false, false, null, "maven2");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, true, true, false, false, null, "maven2");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -72,9 +71,8 @@ public class POMCleanerTest {
     public void testCleanModelloPom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("modello-core.xml");
-        boolean noParent = false;
         instance.getRulesFiles().addDefaultRules();
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, true, false, false, null, "libmodello-java");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, false, true, false, false, null, "libmodello-java");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -84,7 +82,7 @@ public class POMCleanerTest {
         assertEquals("1.0-alpha-22", pomInfo.get("version"));
         assertEquals("debian", pomInfo.get("debianVersion"));
 
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, false, true, true, null, "libmodello-java");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, false, false, true, true, null, "libmodello-java");
         assertXMLEqual(tmpDir.read("modello-core.keep.cleaned"), tmpDir.read(tmpDir.updatedPom()));
         pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -100,9 +98,8 @@ public class POMCleanerTest {
     public void testCleanWagonPom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("wagon-http-lightweight.xml");
-        boolean noParent = false;
         instance.getRulesFiles().addDefaultRules();
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, true, false, false, null, "libwagon-java");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, false, true, false, false, null, "libwagon-java");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -117,10 +114,9 @@ public class POMCleanerTest {
     public void testCleanPlexusContainerDefaultPom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("plexus-container-default.xml");
-        boolean noParent = true;
         instance.getRulesFiles().addDefaultRules();
         instance.getRulesFiles().get(RULES).add(new DependencyRule("org.codehaus.plexus plexus-container-default jar s/1\\.0-alpha-.*/1.0-alpha/"));
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, true, false, false, null, "libplexus-container-default-java");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, true, true, false, false, null, "libplexus-container-default-java");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -135,12 +131,11 @@ public class POMCleanerTest {
     public void testCleanPlexusActiveCollectionsPom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("plexus-active-collections.pom");
-        boolean noParent = true;
         instance.getRulesFiles().addDefaultRules();
         instance.getRulesFiles().get(RULES).add(new DependencyRule("junit junit jar s/3\\..*/3.x/"));
         instance.getRulesFiles().get(RULES).add(new DependencyRule("org.codehaus.plexus plexus-container-default jar s/1\\.0-alpha.*/1.0-alpha/"));
         instance.getRulesFiles().get(RULES).add(new DependencyRule("org.codehaus.plexus plexus-maven-plugin maven-plugin s/.*/1.3.8/"));
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, true, false, false, null, "libplexus-active-collections-java");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, true, true, false, false, null, "libplexus-active-collections-java");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -155,9 +150,8 @@ public class POMCleanerTest {
     public void testCleanPlexusArchiverPom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("plexus-archiver.pom");
-        boolean noParent = true;
         instance.getRulesFiles().addDefaultRules();
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, true, false, false, null, "libplexus-archiver-java");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, true, true, false, false, null, "libplexus-archiver-java");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -172,9 +166,8 @@ public class POMCleanerTest {
     public void testCleanSlf4jPom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("slf4j.xml");
-        boolean noParent = true;
         instance.getRulesFiles().addDefaultRules();
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, true, false, false, null, "libslf4j-java");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, true, true, false, false, null, "libslf4j-java");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -189,10 +182,9 @@ public class POMCleanerTest {
     public void testCleanCommonsValidatorPom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("commons-validator.xml");
-        boolean noParent = true;
         instance.getRulesFiles().addDefaultRules();
         instance.getRulesFiles().get(RULES).add(new DependencyRule("junit junit jar s/3\\..*/3.x/"));
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, true, false, false, null, "libcommons-validator-java");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, true, true, false, false, null, "libcommons-validator-java");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -207,10 +199,9 @@ public class POMCleanerTest {
     public void testCleanServletApiPom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("servlet-api.pom");
-        boolean noParent = true;
         instance.getRulesFiles().addDefaultRules();
         instance.getRulesFiles().get(RULES).add(new DependencyRule("s/org.apache.tomcat/javax.servlet/ servlet-api jar s/.*/2.5/"));
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, true, false, false, null, "libservlet2.5-java");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, true, true, false, false, null, "libservlet2.5-java");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -225,11 +216,10 @@ public class POMCleanerTest {
     public void testCleanHibernateValidatorParentPom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("hibernate-validator-parent.pom");
-        boolean noParent = true;
         instance.getRulesFiles().addDefaultRules();
         instance.getRulesFiles().get(IGNORE).add(new DependencyRule("org.apache.maven.wagon wagon-webdav jar *"));
         instance.getRulesFiles().get(IGNORE).add(new DependencyRule("org.jboss.maven.plugins maven-jdocbook-plugin maven-plugin *"));
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, true, false, false, null, "libhibernate-validator-java");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, true, true, false, false, null, "libhibernate-validator-java");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -244,7 +234,6 @@ public class POMCleanerTest {
     public void testCleanApacheParentPom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("apache.pom");
-        boolean noParent = true;
         instance.getRulesFiles().addDefaultRules();
         instance.getRulesFiles().get(RULES).add(new DependencyRule("org.apache apache-jar-resource-bundle * s/1\\..*/1.x/"));
         instance.getRulesFiles().get(IGNORE).add(new DependencyRule("org.apache.maven.plugins maven-archetype-plugin * *"));
@@ -259,7 +248,7 @@ public class POMCleanerTest {
         instance.getRulesFiles().get(IGNORE).add(new DependencyRule("org.apache.maven.plugins maven-source-plugin * *"));
         instance.addElementToKeep("build");
         instance.addElementToKeep("reporting");
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, false, false, false, null, "libmaven-parent-poms");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, true, false, false, false, null, "libmaven-parent-poms");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -274,12 +263,11 @@ public class POMCleanerTest {
     public void testCleanPlexusUtils2Pom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("plexus-utils2.pom");
-        boolean noParent = false;
         instance.getRulesFiles().addDefaultRules();
         instance.getRulesFiles().get(RULES).add(new DependencyRule("org.codehaus.plexus plexus-utils jar s/2\\..*/2.x/ * *"));
         instance.getRulesFiles().get(RULES).add(new DependencyRule("org.codehaus.plexus plexus pom s/2\\..*/2.x/ * *"));        
         instance.getRulesFiles().get(IGNORE).add(new DependencyRule("org.apache.maven.plugins maven-release-plugin * *"));
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, true, false, false, null, "libplexus-utils2-java");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, false, true, false, false, null, "libplexus-utils2-java");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
@@ -294,7 +282,6 @@ public class POMCleanerTest {
     public void testCleanMojoParentPom() throws Exception {
         pomProperties = tmpDir.newFile("pom.properties");
         File pom = tmpDir.usePom("mojo-parent.pom");
-        boolean noParent = false;
         instance.getRulesFiles().addDefaultRules();
         instance.getRulesFiles().get(RULES).add(new DependencyRule("junit junit jar s/3\\..*/3.x/ * *"));
         instance.getRulesFiles().get(RULES).add(new DependencyRule("org.codehaus codehaus-parent pom s/.*/debian/ * *"));
@@ -308,7 +295,7 @@ public class POMCleanerTest {
         instance.getRulesFiles().get(IGNORE).add(new DependencyRule("org.codehaus.mojo cobertura-maven-plugin * * * *"));
         instance.addElementToKeep("build");
         instance.addElementToKeep("reporting");
-        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, noParent, true, false, false, null, "libmojo-parent-java");
+        instance.cleanPom(pom, tmpDir.updatedPom(), pomProperties, false, true, false, false, null, "libmojo-parent-java");
         assertCleanedXMLEqual();
         Properties pomInfo = new Properties();
         pomInfo.load(new FileInputStream(pomProperties));
